package com.macro.mall.tiny.modules.business.service.impl;

import cn.hutool.core.collection.CollUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.macro.mall.tiny.common.exception.Asserts;
import com.macro.mall.tiny.common.util.MyFileUtils;
import com.macro.mall.tiny.config.UploadConfig;
import com.macro.mall.tiny.modules.business.mapper.BLineMapper;
import com.macro.mall.tiny.modules.business.mapper.BProvinceMapper;
import com.macro.mall.tiny.modules.business.model.BFile;
import com.macro.mall.tiny.modules.business.model.BLine;
import com.macro.mall.tiny.modules.business.model.BProvince;
import com.macro.mall.tiny.modules.business.model.BTower;
import com.macro.mall.tiny.modules.business.service.BLineCacheService;
import com.macro.mall.tiny.modules.business.service.BLineService;
import com.macro.mall.tiny.security.util.AuthUtil;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * <p>
 * 线路表 服务实现类
 * </p>
 *
 * @author macro
 * @since 2021-03-24
 */
@Service
public class BLineServiceImpl extends ServiceImpl<BLineMapper, BLine> implements BLineService {

    @Autowired
    private BLineCacheService lineCacheService;

    @Autowired
    private BLineMapper lineMapper;

    @Autowired
    BProvinceMapper provinceMapper;

    @Override
    public List<BLine> getLineList() {
        List<BLine> lineList = lineCacheService.getLineList();
        if (CollUtil.isNotEmpty(lineList)) {
            return lineList;
        }
        lineList = lineMapper.findListMulti();
        if (CollUtil.isNotEmpty(lineList)) {
            lineCacheService.setLineList(lineList);
        } else {
            lineCacheService.setLineList(new ArrayList<>());
        }
        return lineList;
    }

    @Override
    public List<BLine> findByKey(String key) {
        List<BLine> lineList = lineMapper.findListByKey(key);
        if (StringUtils.isNotBlank(key)) {
            lineList.forEach(line -> {
                if (!line.getProvince().contains(key) && !line.getName().contains(key)) {
                    String keyLow = key.toLowerCase();
                    Set<String> matchShapeList = line.getTowerList().stream()
                            .filter(tower-> tower.getShape().toLowerCase().contains(keyLow))
                            .map(BTower::getShape).collect(Collectors.toSet());
                    line.setMatchShapeList(matchShapeList);
                }
            });
        }
        return lineList;
    }

    @Override
    public List<BFile> getFile(Long id) {
        boolean auth = AuthUtil.checkAccess(AuthUtil.ACCESS);
        BLine line = lineMapper.selectById(id);
        if (line == null) Asserts.fail("该线路不存在，id：" + id);
        BProvince province = provinceMapper.selectById(line.getProvinceId());
        String basePath = UploadConfig.powerPath +
                province.getProvince() + UploadConfig.SEPARATOR +
                line.getName();
        return MyFileUtils.getSubBFiles(basePath, auth);
    }
}
